package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Nov 18, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
hello
just say hello
Install
import code
go get gitee.com/tut/hello@latest
install cmd
go install gitee.com/tut/hello/cmd/hello@latest
Example
Here's a simple example as follows:
package main
import (
"fmt"
"gitee.com/tut/hello"
)
func main() {
result := hello.Hello("jack")
fmt.Println(result)
}
Documentation
¶
Hello returns hello message
Source Files
¶
Directories
¶
cmd
|
|
hello
command
cmd/hello/main.go
|
cmd/hello/main.go |
Click to show internal directories.
Click to hide internal directories.